@@ -215,3 +215,25 @@ class FlaviusPaymentComplete(FlaviusBase):
         super(FlaviusPaymentComplete, self).__init__(search_url='', create_url='',
                                                      update_url=conf.FLAVIUS_API_PAYMENT_COMPLETE,
                                                      delete_url='')
+
+
+class FlaviusPickupLocation(FlaviusBase):
+    """
+    Flaviusの受取場所マスタを操作するAPI
+    """
+    def __init__(self):
+        super(FlaviusPickupLocation, self).__init__(search_url=conf.FLAVIUS_API_PICKUP_LOCATION_LIST,
+                                                    create_url=conf.FLAVIUS_API_PICKUP_LOCATION_REGIST,
+                                                    update_url=conf.FLAVIUS_API_PICKUP_LOCATION_REGIST,
+                                                    delete_url=conf.FLAVIUS_API_PICKUP_LOCATION_DELETE)
+
+
+class FlaviusPickupTime(FlaviusBase):
+    """
+    Flaviusの受取時間マスタを操作するAPI
+    """
+    def __init__(self):
+        super(FlaviusPickupTime, self).__init__(search_url=conf.FLAVIUS_API_PICKUP_TIME_LIST,
+                                                create_url=conf.FLAVIUS_API_PICKUP_TIME_REGIST,
+                                                update_url=conf.FLAVIUS_API_PICKUP_TIME_REGIST,
+                                                delete_url=conf.FLAVIUS_API_PICKUP_TIME_DELETE)
