@@ -90,6 +90,30 @@ class Settings:
     def FLAVIUS_API_PAYMENT_COMPLETE(self):
         return getattr(settings, "FLAVIUS_API_PAYMENT_COMPLETE", 'api/payment_complete.php')
 
+    @property
+    def FLAVIUS_API_PICKUP_LOCATION_LIST(self):
+        return getattr(settings, "FLAVIUS_API_PICKUP_LOCATION_LIST", 'api/pickup_location_list.php')
+
+    @property
+    def FLAVIUS_API_PICKUP_LOCATION_REGIST(self):
+        return getattr(settings, "FLAVIUS_API_PICKUP_LOCATION_REGIST", 'api/pickup_location_regist.php')
+
+    @property
+    def FLAVIUS_API_PICKUP_LOCATION_DELETE(self):
+        return getattr(settings, "FLAVIUS_API_PICKUP_LOCATION_DELETE", 'api/pickup_location_delete.php')
+
+    @property
+    def FLAVIUS_API_PICKUP_TIME_LIST(self):
+        return getattr(settings, "FLAVIUS_API_PICKUP_TIME_LIST", 'api/pickup_time_list.php')
+
+    @property
+    def FLAVIUS_API_PICKUP_TIME_REGIST(self):
+        return getattr(settings, "FLAVIUS_API_PICKUP_TIME_REGIST", 'api/pickup_time_regist.php')
+
+    @property
+    def FLAVIUS_API_PICKUP_TIME_DELETE(self):
+        return getattr(settings, "FLAVIUS_API_PICKUP_TIME_DELETE", 'api/pickup_time_delete.php')
+
     @property
     def EXCLUDE_TAX(self):
         return getattr(settings, "EXCLUDE_TAX", '91100')
